@@ -257,8 +257,7 @@ gtk_source_gutter_dispose (GObject *object)
 	GtkSourceGutter *gutter = GTK_SOURCE_GUTTER (object);
 	gint i;
 
-	g_list_foreach (gutter->priv->renderers, (GFunc)renderer_free, NULL);
-	g_list_free (gutter->priv->renderers);
+	g_list_free_full (gutter->priv->renderers, (GDestroyNotify)renderer_free);
 
 	if (gutter->priv->view)
 	{
@@ -1610,3 +1609,32 @@ gtk_source_gutter_get_padding (GtkSourceGutter *gutter,
 		*ypad = gutter->priv->ypad;
 	}
 }
+
+/**
+ * gtk_source_gutter_get_renderer_at_pos:
+ * @gutter: A #GtkSourceGutter.
+ * @x: The x position to get identified.
+ * @y: The y position to get identified.
+ *
+ * Finds the #GtkSourceGutterRenderer at (x, y).
+ *
+ * Returns: (transfer none): the renderer at (x, y) or %NULL.
+ */
+GtkSourceGutterRenderer *
+gtk_source_gutter_get_renderer_at_pos (GtkSourceGutter *gutter,
+                                       gint             x,
+                                       gint             y)
+{
+	Renderer *renderer;
+
+	g_return_val_if_fail (GTK_SOURCE_IS_GUTTER (gutter), NULL);
+
+	renderer = renderer_at_x (gutter, x, NULL, NULL);
+
+	if (renderer == NULL)
+	{
+		return NULL;
+	}
+
+	return renderer->renderer;
+}
