@@ -171,7 +171,7 @@ static void
 gtk_source_style_scheme_manager_init (GtkSourceStyleSchemeManager *mgr)
 {
 	mgr->priv = G_TYPE_INSTANCE_GET_PRIVATE (mgr,
-						 GTK_TYPE_SOURCE_STYLE_SCHEME_MANAGER,
+						 GTK_SOURCE_TYPE_STYLE_SCHEME_MANAGER,
 						 GtkSourceStyleSchemeManagerPrivate);
 	mgr->priv->schemes_hash = NULL;
 	mgr->priv->ids = NULL;
@@ -190,7 +190,7 @@ gtk_source_style_scheme_manager_init (GtkSourceStyleSchemeManager *mgr)
 GtkSourceStyleSchemeManager *
 gtk_source_style_scheme_manager_new (void)
 {
-	return g_object_new (GTK_TYPE_SOURCE_STYLE_SCHEME_MANAGER, NULL);
+	return g_object_new (GTK_SOURCE_TYPE_STYLE_SCHEME_MANAGER, NULL);
 }
 
 /**
@@ -198,7 +198,7 @@ gtk_source_style_scheme_manager_new (void)
  *
  * Returns the default #GtkSourceStyleSchemeManager instance.
  *
- * Returns: (transfer-none): a #GtkSourceStyleSchemeManager. Return value
+ * Returns: (transfer none): a #GtkSourceStyleSchemeManager. Return value
  * is owned by GtkSourceView library and must not be unref'ed.
  */
 GtkSourceStyleSchemeManager *
@@ -382,8 +382,7 @@ reload_if_needed (GtkSourceStyleSchemeManager *mgr)
 
 	ids = check_parents (ids, schemes_hash);
 
-	g_slist_foreach (files, (GFunc) g_free, NULL);
-	g_slist_free (files);
+	g_slist_free_full (files, g_free);
 
 	free_schemes (mgr);
 
@@ -420,7 +419,7 @@ gtk_source_style_scheme_manager_set_search_path (GtkSourceStyleSchemeManager  *m
 {
 	gchar **tmp;
 
-	g_return_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager));
+	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager));
 
 	tmp = manager->priv->search_path;
 
@@ -449,7 +448,7 @@ gtk_source_style_scheme_manager_append_search_path (GtkSourceStyleSchemeManager
 {
 	guint len = 0;
 
-	g_return_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager));
+	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager));
 	g_return_if_fail (path != NULL);
 
 	if (manager->priv->search_path == NULL)
@@ -485,7 +484,7 @@ gtk_source_style_scheme_manager_prepend_search_path (GtkSourceStyleSchemeManager
 	guint len = 0;
 	gchar **new_search_path;
 
-	g_return_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager));
+	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager));
 	g_return_if_fail (path != NULL);
 
 	if (manager->priv->search_path == NULL)
@@ -512,14 +511,14 @@ gtk_source_style_scheme_manager_prepend_search_path (GtkSourceStyleSchemeManager
  * Returns the current search path for the @manager.
  * See gtk_source_style_scheme_manager_set_search_path() for details.
  *
- * Returns: (array zero-terminated) (tranfer none): a %NULL-terminated array
+ * Returns: (array zero-terminated=1) (transfer none): a %NULL-terminated array
  * of string containing the search path.
  * The array is owned by the @manager and must not be modified.
  */
-G_CONST_RETURN gchar* G_CONST_RETURN *
+const gchar * const *
 gtk_source_style_scheme_manager_get_search_path (GtkSourceStyleSchemeManager *manager)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager), NULL);
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager), NULL);
 
 	if (manager->priv->search_path == NULL)
 		manager->priv->search_path = _gtk_source_view_get_default_dirs (STYLES_DIR, FALSE);
@@ -538,7 +537,7 @@ gtk_source_style_scheme_manager_get_search_path (GtkSourceStyleSchemeManager *ma
 void
 gtk_source_style_scheme_manager_force_rescan (GtkSourceStyleSchemeManager *manager)
 {
-	g_return_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager));
+	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager));
 
 	manager->priv->need_reload = TRUE;
 
@@ -555,10 +554,10 @@ gtk_source_style_scheme_manager_force_rescan (GtkSourceStyleSchemeManager *manag
  * of string containing the ids of the available style schemes or %NULL if no
  * style scheme is available. The array is owned by the @manager and must not be modified.
  */
-G_CONST_RETURN gchar* G_CONST_RETURN *
+const gchar * const *
 gtk_source_style_scheme_manager_get_scheme_ids (GtkSourceStyleSchemeManager *manager)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager), NULL);
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager), NULL);
 
 	reload_if_needed (manager);
 
@@ -579,7 +578,7 @@ GtkSourceStyleScheme *
 gtk_source_style_scheme_manager_get_scheme (GtkSourceStyleSchemeManager *manager,
 					    const gchar                 *scheme_id)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_STYLE_SCHEME_MANAGER (manager), NULL);
+	g_return_val_if_fail (GTK_SOURCE_IS_STYLE_SCHEME_MANAGER (manager), NULL);
 	g_return_val_if_fail (scheme_id != NULL, NULL);
 
 	reload_if_needed (manager);
